@@ -19,4 +19,4 @@ DeepSparse server implementation to serve ONNX files and pipelines through
 the DeepSparse Engine.
 """
 
-from .main import start_server
+from .cli import main
