@@ -18,26 +18,34 @@ Helper functions for working with ONNX exports of transformer models and deepspa
 
 
 import os
+import re
 from pathlib import Path
 from tempfile import NamedTemporaryFile
-from typing import List, Optional, Tuple
+from typing import List, Optional, Tuple, Union
 
 import numpy
 import onnx
+from onnx import ModelProto
 
-from sparsezoo import Zoo
+from deepsparse.log import get_main_logger
+from deepsparse.utils.onnx import truncate_onnx_model
+from sparsezoo import Model
 
 
 __all__ = [
     "get_onnx_path_and_configs",
     "overwrite_transformer_onnx_model_inputs",
     "fix_numpy_types",
+    "get_transformer_layer_init_names",
+    "truncate_transformer_onnx_model",
 ]
 
+_LOGGER = get_main_logger()
 
 _MODEL_DIR_ONNX_NAME = "model.onnx"
 _MODEL_DIR_CONFIG_NAME = "config.json"
 _MODEL_DIR_TOKENIZER_NAME = "tokenizer.json"
+_MODEL_DIR_TOKENIZER_CONFIG_NAME = "tokenizer_config.json"
 
 
 def get_onnx_path_and_configs(
@@ -62,6 +70,7 @@ def get_onnx_path_and_configs(
 
     config_path = None
     tokenizer_path = None
+
     if os.path.isdir(model_path):
         model_files = os.listdir(model_path)
 
@@ -93,14 +102,19 @@ def get_onnx_path_and_configs(
             tokenizer_path = model_path
 
     elif model_path.startswith("zoo:"):
-        zoo_model = Zoo.load_model_from_stub(model_path)
-        onnx_path = zoo_model.onnx_file.downloaded_path()
-
-        for framework_file in zoo_model.framework_files:
-            if framework_file.display_name == _MODEL_DIR_CONFIG_NAME:
-                config_path = _get_file_parent(framework_file.downloaded_path())
-            if "tokenizer.json" in framework_file.display_name:
-                tokenizer_path = _get_file_parent(framework_file.downloaded_path())
+        zoo_model = Model(model_path)
+        onnx_path = zoo_model.onnx_model.path
+        config_path = _get_file_parent(
+            zoo_model.deployment.default.get_file(_MODEL_DIR_CONFIG_NAME).path
+        )
+        tokenizer_path = _get_file_parent(
+            zoo_model.deployment.default.get_file(_MODEL_DIR_TOKENIZER_NAME).path
+        )
+        tokenizer_config_path = zoo_model.deployment.default.get_file(
+            _MODEL_DIR_TOKENIZER_CONFIG_NAME
+        )
+        if tokenizer_config_path is not None:
+            tokenizer_config_path.path  # trigger download of tokenizer_config
     elif require_configs and (config_path is None or tokenizer_path is None):
         raise RuntimeError(
             f"Unable to find model and tokenizer config for model_path {model_path}. "
@@ -193,3 +207,105 @@ def fix_numpy_types(func):
         return result
 
     return _wrapper
+
+
+def get_transformer_layer_init_names(model: ModelProto) -> List[str]:
+    """
+    Attempts to find the names of the initializers corresponding to the last nodes
+    in a bert or distillbert layer. Throws RuntimeError if cannot find initializer
+    names matching the expected formats.
+
+    :param model: model containing bert or distilbert layers
+    :return: a list of initializer names belonging to nodes at the end of the
+        transformer layer
+    """
+    bert_layer_pattern = re.compile(
+        r"bert\.encoder\.layer\.\d+\.output\.LayerNorm\.bias"
+    )
+    distillbert_layer_pattern = re.compile(
+        r"distilbert.transformer.layer.\d+\.output_layer_norm.bias"
+    )
+
+    layer_init_names = [
+        initializer.name
+        for initializer in model.graph.initializer
+        if bert_layer_pattern.match(initializer.name)
+        or distillbert_layer_pattern.match(initializer.name)
+    ]
+    if len(layer_init_names) <= 0:
+        raise RuntimeError(
+            "Unable to find bert layers within onnx graph using initializer "
+            "name matching"
+        )
+
+    return sorted(
+        layer_init_names,
+        key=lambda name: int(re.findall("[0-9]+", name)[0]),
+        reverse=False,
+    )
+
+
+def truncate_transformer_onnx_model(
+    model_path: str,
+    emb_extraction_layer: Union[int, str] = -1,
+    hidden_layer_size: Optional[int] = None,
+    output_name: str = "embedding",
+    output_path: Optional[str] = None,
+) -> Tuple[str, List[str], Union[NamedTemporaryFile, None]]:
+    """
+    Determines where to cut the transformer model using best-guess heuristics
+    Saves cut model to output_path or temporary file
+
+    :param model_path: path of onnx file to be cut
+    :param emb_extraction_layer: if an int, last bert layer to include. If a
+        string, then the name of the last node in the truncated graph.
+        default -1 (last layer)
+    :param hidden_layer_size: guess for the number of embedded values per token
+        in provided model. Used by deepsparse engine to optimize memory allocation
+    :param output_name: name of graph output, default "embedding"
+    :param output_path: path to write resulting onnx file. If not provided,
+        will create a temporary file path that will be destroyed on program end
+    :return: if no output path, a tuple of the saved path to the model, list of
+        model output names, and reference to the tempfile object will be returned
+        otherwise, a tuple containing the given output_path argument, the model
+        output names, and None
+    """
+
+    # determine where to cut the model
+    final_node_name = (
+        emb_extraction_layer if isinstance(emb_extraction_layer, str) else None
+    )
+    if final_node_name is None:
+        model = onnx.load(model_path)
+
+        # try to match bert layers by initializer names
+        try:
+            layer_init_names_sorted = get_transformer_layer_init_names(model)
+            final_node_initializer_name = layer_init_names_sorted[emb_extraction_layer]
+            final_node_name = [
+                node.name
+                for node in model.graph.node
+                if final_node_initializer_name in node.input
+            ][0]
+        except Exception as exception:
+            raise RuntimeError(f"Failed to truncate transformer: {exception}")
+
+    # create temporary file if necessary
+    if output_path is None:
+        tmp_file = NamedTemporaryFile()  # file will be deleted after program exit
+        output_filepath = tmp_file.name
+        tmp_file_or_none = tmp_file
+    else:
+        output_filepath = output_path
+        tmp_file_or_none = None
+
+    # create subgraph
+    truncate_onnx_model(
+        onnx_filepath=model_path,
+        output_filepath=output_filepath,
+        final_node_names=[final_node_name],
+        graph_output_names=[output_name],
+        graph_output_shapes=[[None, hidden_layer_size]],
+    )
+
+    return output_filepath, [output_name], tmp_file_or_none
